@@ -37,16 +37,16 @@ pub fn round_zeros<T: Roundable>(number: T, zeros: u32) -> T {
 /// # Examples
 ///
 /// ```
-/// use common_math::rounding::round_up;
+/// use common_math::rounding::ceil;
 ///
-/// assert_eq!(round_up(123.454_f64, 2), 123.46_f64);
-/// assert_eq!(round_up(123.456_f64, 0), 124_f64);
-/// assert_eq!(round_up(123.454_f32, 2), 123.46_f32);
+/// assert_eq!(ceil(123.454_f64, 2), 123.46_f64);
+/// assert_eq!(ceil(123.456_f64, 0), 124_f64);
+/// assert_eq!(ceil(123.454_f32, 2), 123.46_f32);
 /// ```
 #[inline]
-pub fn round_up<T: Float>(number: T, decimal_places: u32) -> T {
+pub fn ceil<T: Float>(number: T, decimal_places: u32) -> T {
     let power = 10_f64.powi(decimal_places as i32);
-    number.apply_round_up(power)
+    number.apply_ceil(power)
 }
 
 /// Returns the number rounded up to a given number of zeros
@@ -54,16 +54,16 @@ pub fn round_up<T: Float>(number: T, decimal_places: u32) -> T {
 /// # Examples
 ///
 /// ```
-/// use common_math::rounding::round_up_zeros;
+/// use common_math::rounding::ceil_zeros;
 ///
-/// assert_eq!(round_up_zeros(123.456_f64, 1), 130_f64);
-/// assert_eq!(round_up_zeros(123.456_f64, 0), 124_f64);
-/// assert_eq!(round_up_zeros(123_i32, 2), 200_i32);
+/// assert_eq!(ceil_zeros(123.456_f64, 1), 130_f64);
+/// assert_eq!(ceil_zeros(123.456_f64, 0), 124_f64);
+/// assert_eq!(ceil_zeros(123_i32, 2), 200_i32);
 /// ```
 #[inline]
-pub fn round_up_zeros<T: Roundable>(number: T, zeros: u32) -> T {
+pub fn ceil_zeros<T: Roundable>(number: T, zeros: u32) -> T {
     let power = 10_f64.powi(-(zeros as i32));
-    number.apply_round_up_zeros(power)
+    number.apply_ceil_zeros(power)
 }
 
 /// Returns the number rounded down to a given number of decimal places
@@ -71,16 +71,16 @@ pub fn round_up_zeros<T: Roundable>(number: T, zeros: u32) -> T {
 /// # Examples
 ///
 /// ```
-/// use common_math::rounding::round_dn;
+/// use common_math::rounding::floor;
 ///
-/// assert_eq!(round_dn(123.456_f64, 2), 123.45_f64);
-/// assert_eq!(round_dn(123.456_f64, 0), 123_f64);
-/// assert_eq!(round_dn(123.454_f32, 2), 123.454_f32);
+/// assert_eq!(floor(123.456_f64, 2), 123.45_f64);
+/// assert_eq!(floor(123.456_f64, 0), 123_f64);
+/// assert_eq!(floor(123.454_f32, 2), 123.454_f32);
 /// ```
 #[inline]
-pub fn round_dn<T: Float>(number: T, decimal_places: u32) -> T {
+pub fn floor<T: Float>(number: T, decimal_places: u32) -> T {
     let power = 10_f64.powi(decimal_places as i32);
-    number.apply_round_dn(power)
+    number.apply_floor(power)
 }
 
 /// Returns the number rounded down to a given number of zeros
@@ -88,16 +88,16 @@ pub fn round_dn<T: Float>(number: T, decimal_places: u32) -> T {
 /// # Examples
 ///
 /// ```
-/// use common_math::rounding::round_dn_zeros;
+/// use common_math::rounding::floor_zeros;
 ///
-/// assert_eq!(round_dn_zeros(123.456_f64, 1), 120_f64);
-/// assert_eq!(round_dn_zeros(123.654_f64, 0), 123_f64);
-/// assert_eq!(round_dn_zeros(156_i32, 2), 100_i32);
+/// assert_eq!(floor_zeros(123.456_f64, 1), 120_f64);
+/// assert_eq!(floor_zeros(123.654_f64, 0), 123_f64);
+/// assert_eq!(floor_zeros(156_i32, 2), 100_i32);
 /// ```
 #[inline]
-pub fn round_dn_zeros<T: Roundable>(number: T, zeros: u32) -> T {
+pub fn floor_zeros<T: Roundable>(number: T, zeros: u32) -> T {
     let power = 10_f64.powi(-(zeros as i32));
-    number.apply_round_dn_zeros(power)
+    number.apply_floor_zeros(power)
 }
 
 /// Returns the number rounded to a given number of significant figures
@@ -145,8 +145,8 @@ where
 
 pub trait Float {
     fn apply_round(self, power: f64) -> Self;
-    fn apply_round_up(self, power: f64) -> Self;
-    fn apply_round_dn(self, power: f64) -> Self;
+    fn apply_ceil(self, power: f64) -> Self;
+    fn apply_floor(self, power: f64) -> Self;
     fn private_trunc(self) -> Self;
     fn private_to_string(self) -> String;
 }
@@ -156,11 +156,11 @@ impl Float for f32 {
         (self * power as f32).round() / power as f32
     }
 
-    fn apply_round_up(self, power: f64) -> f32 {
+    fn apply_ceil(self, power: f64) -> f32 {
         (self * power as f32).ceil() / power as f32
     }
 
-    fn apply_round_dn(self, power: f64) -> f32 {
+    fn apply_floor(self, power: f64) -> f32 {
         (self * power as f32).floor() / power as f32
     }
 
@@ -178,11 +178,11 @@ impl Float for f64 {
         (self * power).round() / power
     }
 
-    fn apply_round_up(self, power: f64) -> f64 {
+    fn apply_ceil(self, power: f64) -> f64 {
         (self * power).ceil() / power
     }
 
-    fn apply_round_dn(self, power: f64) -> f64 {
+    fn apply_floor(self, power: f64) -> f64 {
         (self * power).floor() / power
     }
 
@@ -197,8 +197,8 @@ impl Float for f64 {
 
 pub trait Roundable {
     fn apply_round_zeros(self, power: f64) -> Self;
-    fn apply_round_up_zeros(self, power: f64) -> Self;
-    fn apply_round_dn_zeros(self, power: f64) -> Self;
+    fn apply_ceil_zeros(self, power: f64) -> Self;
+    fn apply_floor_zeros(self, power: f64) -> Self;
 }
 
 impl Roundable for f32 {
@@ -206,11 +206,11 @@ impl Roundable for f32 {
         (self * power as f32).round() / power as f32
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> f32 {
+    fn apply_ceil_zeros(self, power: f64) -> f32 {
         (self * power as f32).ceil() / power as f32
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> f32 {
+    fn apply_floor_zeros(self, power: f64) -> f32 {
         (self * power as f32).floor() / power as f32
     }
 }
@@ -220,11 +220,11 @@ impl Roundable for f64 {
         (self * power).round() / power
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> f64 {
+    fn apply_ceil_zeros(self, power: f64) -> f64 {
         (self * power).ceil() / power
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> f64 {
+    fn apply_floor_zeros(self, power: f64) -> f64 {
         (self * power).floor() / power
     }
 }
@@ -234,11 +234,11 @@ impl Roundable for i8 {
         ((self as f64 * power).round() / power) as i8
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> i8 {
+    fn apply_ceil_zeros(self, power: f64) -> i8 {
         ((self as f64 * power).ceil() / power) as i8
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> i8 {
+    fn apply_floor_zeros(self, power: f64) -> i8 {
         ((self as f64 * power).floor() / power) as i8
     }
 }
@@ -248,11 +248,11 @@ impl Roundable for i16 {
         ((self as f64 * power).round() / power) as i16
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> i16 {
+    fn apply_ceil_zeros(self, power: f64) -> i16 {
         ((self as f64 * power).ceil() / power) as i16
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> i16 {
+    fn apply_floor_zeros(self, power: f64) -> i16 {
         ((self as f64 * power).floor() / power) as i16
     }
 }
@@ -262,11 +262,11 @@ impl Roundable for i32 {
         ((self as f64 * power).round() / power) as i32
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> i32 {
+    fn apply_ceil_zeros(self, power: f64) -> i32 {
         ((self as f64 * power).ceil() / power) as i32
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> i32 {
+    fn apply_floor_zeros(self, power: f64) -> i32 {
         ((self as f64 * power).floor() / power) as i32
     }
 }
@@ -276,11 +276,11 @@ impl Roundable for i64 {
         ((self as f64 * power).round() / power) as i64
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> i64 {
+    fn apply_ceil_zeros(self, power: f64) -> i64 {
         ((self as f64 * power).ceil() / power) as i64
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> i64 {
+    fn apply_floor_zeros(self, power: f64) -> i64 {
         ((self as f64 * power).floor() / power) as i64
     }
 }
@@ -290,11 +290,11 @@ impl Roundable for u8 {
         ((self as f64 * power).round() / power) as u8
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> u8 {
+    fn apply_ceil_zeros(self, power: f64) -> u8 {
         ((self as f64 * power).ceil() / power) as u8
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> u8 {
+    fn apply_floor_zeros(self, power: f64) -> u8 {
         ((self as f64 * power).floor() / power) as u8
     }
 }
@@ -304,11 +304,11 @@ impl Roundable for u16 {
         ((self as f64 * power).round() / power) as u16
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> u16 {
+    fn apply_ceil_zeros(self, power: f64) -> u16 {
         ((self as f64 * power).ceil() / power) as u16
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> u16 {
+    fn apply_floor_zeros(self, power: f64) -> u16 {
         ((self as f64 * power).floor() / power) as u16
     }
 }
@@ -318,11 +318,11 @@ impl Roundable for u32 {
         ((self as f64 * power).round() / power) as u32
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> u32 {
+    fn apply_ceil_zeros(self, power: f64) -> u32 {
         ((self as f64 * power).ceil() / power) as u32
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> u32 {
+    fn apply_floor_zeros(self, power: f64) -> u32 {
         ((self as f64 * power).floor() / power) as u32
     }
 }
@@ -332,11 +332,11 @@ impl Roundable for u64 {
         ((self as f64 * power).round() / power) as u64
     }
 
-    fn apply_round_up_zeros(self, power: f64) -> u64 {
+    fn apply_ceil_zeros(self, power: f64) -> u64 {
         ((self as f64 * power).ceil() / power) as u64
     }
 
-    fn apply_round_dn_zeros(self, power: f64) -> u64 {
+    fn apply_floor_zeros(self, power: f64) -> u64 {
         ((self as f64 * power).floor() / power) as u64
     }
 }
